function xp = qcm_simple_freq_response_f(t,x)
% quarter car model with standard and sky-hook damper
% excited by a sweep sine

global  sky_hook
global  mass_c  mass_w  c_susp  d_susp  d_c d_w t_d  c_tire
global  g_const f0_susp  f0_tire  ftire  zcpp 
global  q  p  amp_0

% get states
zc=x(1);  zw=x(2);  zcp=x(3);  zwp=x(4); d=x(5);   

% road
arg = 2*pi/q*log(p./(p-q*t));  z_road = amp_0*sin(arg);  

% tire force
ftire = max(0,f0_tire+c_tire*(z_road-zw)); 

% spring force
fs = f0_susp + c_susp*(zw-zc); 

% damping force
fd = d*(zwp-zcp);  

% compute skyhook damping parameter 
if abs(zcp-zwp) > 1.d-2
  d_sky = (d_c*zcp-d_w*zwp)/(zcp-zwp); % nonlinear damping
else
  d_sky = d; % keep pld value
end

switch sky_hook 
  case 0, dp=(d_susp-d)/t_d; % standard damper            
  case 1, dp=(d_sky -d)/t_d; % sky hook active
  case 2, d_sky=max(0,d_sky); dp=(d_sky-d)/t_d; % sky hook passive
end

% accelerations
zcpp = (         (fs+fd) ) / mass_c  -  g_const ;
zwpp = ( ftire - (fs+fd) ) / mass_w  -  g_const ;

% state derivatives
xp = [ zcp; zwp;  zcpp; zwpp;  dp ];

end