function xdot = steering_system_f(t,x)

% data + output quantities
global A_SW  f_SW
global a  s  m_R  Thetaz  i_SB  i_SL  c_S d_S  fr_mx 
global df_0 f_m s_m f_s s_s vt_n  c_bo d_bo r_b
global dsw d1 d2  ftg fsf  tss

% states (standalone model without steering wheel)
ur    = x(1);  urdot = x(2); % rack displacement and velocity
ga1   = x(3);  ga2   = x(4); % left and right tire torsional deflection

% soft periodic steering wheel input
dsw = A_SW*sin(2*pi*f_SW*t)^2; dswdot=2*A_SW*sin(4*pi*f_SW*t)*pi*f_SW;
if t > 0.5/f_SW, dsw=-dsw; dswdot = -dswdot; end 
d   = i_SL*ur; tand = tan(d); % average wheel steering angle

% kinematics of steering linkage (ackermann geometry)
d1   = atan2( a*tand , a-0.5*s*tand );
dd1  = i_SL * a^2/(a-0.5*s*tand)^2 * cos(d1)^2/cos(d)^2 ; d1dot= dd1*urdot;
d2   = atan2( a*tand , a+0.5*s*tand );
dd2  = i_SL * a^2/(a+0.5*s*tand)^2 * cos(d2)^2/cos(d)^2 ; d2dot= dd2*urdot;

mrg = m_R+(dd1^2+dd2^2)*Thetaz; % general. rack mass, thetaz1=thetaz2=thetaz
tss = c_S*(dsw-i_SB*ur)+d_S*(dswdot-i_SB*urdot); % torque in steering column
fsm = i_SB*tss; % steering torque converted to rack force

% left bore torque (enhanced model @ stand still, vt=vt_n)
sb = -r_b*d1dot/vt_n; sg = abs(sb); % bore slip and generalized slip
[f,fos] = tmy_fcombined(sg,df_0,f_m,s_m,f_s,s_s); % combined tire force 
ga1dot=-(c_bo*ga1*vt_n+fos*d1dot*r_b^2)/(d_bo*vt_n+fos*r_b^2); % twist dyn.  
tbo1 = c_bo*ga1 + d_bo*ga1dot ;  % bore torque

% right bore torque (enhanced model @ stand still, vt=vt_n)
sb = -r_b*d2dot/vt_n;  sg = abs(sb); % bore slip and generalized slip
[f,fos] = tmy_fcombined(sg,df_0,f_m,s_m,f_s,s_s); % combined tire force 
ga2dot=-(c_bo*ga2*vt_n+fos*d2dot*r_b^2)/(d_bo*vt_n+fos*r_b^2); % twist dyn.     
tbo2 = c_bo*ga2 + d_bo*ga2dot ;  % bore torque

ftg = dd1*tbo1 + dd2*tbo2 ;  % generalized tire torques applied to rack

% enhanced dry friction model
fsfst = ftg + fsm ;  % static part
dN = i_SB * sqrt( c_S * mrg ) ;  % numerical damping adjusted to data
fsf = fsfst + dN*urdot; fsf = sign(fsf)*min(abs(fsf),fr_mx); % friction force 

urdotdot = ( ftg+fsm-fsf ) / mrg ; % rack acceleration (equations of motion)
xdot = [ urdot; urdotdot; ga1dot; ga2dot ]; % state derivatives

end