clear all, close all

% data + output quantities
global  A_SW  f_SW
global  a  s  m_R  Thetaz  i_SB  i_SL  c_S d_S  fr_mx 
global  df_0 f_m s_m f_s s_s vt_n  c_bo d_bo r_b
global  dsw d1 d2  ftg fsf  tss

A_SW = 540/180*pi; % steering wheel amplitude [rad]
f_SW     = 0.2;    % steering frequency [Hz]
a        = 2.7;    % wheel_base [m] 
s        = 1.5;    % track_width [m]
m_R      = 2.5;    % mass of rack [kg]
Thetaz   = 1.3;    % inertia of wheel body and wheel around z-axis [kgm^2]
i_SB     = 125;    % ratio steering wheel angle / rack displacement [rad/m]
i_SL     = 9.3;    % ratio wheel steering angle / rack displacement [rad/m]
c_S      = 573;    % stiffness of steering shaft [Nm/rad]
d_S      = 5;      % damping of steering shaft [Nm/(rad/s)]
fr_mx    = 120;    % maximum friction force in steering box [N]
df_0     = 90000;  % tire force initial inclination [N/-]
f_m      = 4250;   % maximum tire force [N]
s_m      = 0.18;   % slip where f=f_m [-]
f_s      = 4100;   % sliding force [N]
s_s      = 0.5;    % slip where f=f_s [-]
vt_n     = 0.01;   % fictitious velocity [m/s]
c_bo     = 2400;   % torsional tire stiffness [Nm/rad]
d_bo     = 2;      % torsional tire damping [Nm/(rad/s)]
r_b      = 0.065;  % equivalent bore radius [m]

% perorm simulation over one period of a sinusoidal steer input 
t0=0; tE=1/f_SW; x0 = [0; 0; 0; 0 ];
tic; [tout,xout]=ode23(@steering_system_f,[t0,tE],x0); toc

% pre-allocate output-quantities to speed up loop and plot some results
io=length(tout); z=zeros(io,1); dswi=z;d1i=z;d2i=z; ftgi=z;fsfi=z; tssi=z;
for i=1:io
  xp=feval(@steering_system_f,tout(i),xout(i,:));
  dswi(i)=dsw; d1i(i)=d1; d2i(i)=d2; ftgi(i)=ftg; fsfi(i)=fsf; tssi(i)=tss;
end
subplot(2,2,1)
  plot(dswi*180/pi,-tssi), grid on 
  title('steering torque [Nm] / steering wheel angle [Grad]') 
  xy=axis; axis([[-1,1]*A_SW*180/pi,xy(3),xy(4)])
subplot(2,2,2)
  plot(tout,(xout(:,1)*i_SB-dswi)*180/pi), grid on,
  title('twist angle of steering shaft [Grad]')
  xy=axis; axis([0,tE,xy(3),xy(4)])
subplot(2,2,3)
  plot(tout,[d1i,d2i,-xout(:,3:4)]*180/pi), grid on
  legend('wheel left','wheel right','tire twist left','tire twist right')
  xy=axis; axis([0,tE,xy(3),xy(4)])
subplot(2,2,4)
  [AX,H1,H2]=plotyy(tout,ftgi/1000,tout,fsfi); grid on
  legend('generalized tire force [kN]','friction force [N]')
  set(AX(1),'XLim',[0 tE]); set(AX(2),'XLim',[0 tE])

figure
t=linspace(0,tE,101);
dsw = A_SW*sin(2*pi*f_SW*t);  % steering wheel input 
tand = tan(dsw/i_SB*i_SL); % average wheel steering angle
d1   = atan2( a*tand , a-0.5*s*tand );
d2   = atan2( a*tand , a+0.5*s*tand );
subplot(2,2,1)
  plot(dsw*180/pi,[d1;d2]*180/pi), grid on 
  legend('left','right') 


  
