% frequency response of a hydro-mount
clear all %, close all

% globals
global  mf  cf  sf  df   p  q  amp  

% define sweep sine excitation
f0 =   1;      % lowest frequency [Hz]
fe =   100;    % highest frequency [Hz]
n  =   50;     % number of frequency interval
amp=  0.0005;  % amplitude [m]

% sweep sine parameter
q = 1/n * log ( fe/f0 ) ;   p = q / ( f0 * ( 1 - (f0/fe)^(1/n) ) ) ;

% model data
mf=25;          % generalized fluid mass [kg]
cm=125000;      % stiffness of main spring [N/m]
df=750;         % fluid damping [N/(m/s)]
cf=100000;      % fluid stiffness [N/m]
sf=0.0002;      % clearance in mebrane support [m]

% pre-allocate vars to speed up loop
freq=zeros(n+1,1); f0=zeros(n+1,1); fs=zeros(n+1,1); fc=zeros(n+1,1);

t0=0; s0=0; sd0=0;  x0 = [ s0 sd0 ];  % initial condition first cycle
for ifreq=1:n+1
  
% Integrate from t0 to te results in  freq = 1/(te-t0)
  te=p/q*(1-exp(-ifreq*q));  
  freq(ifreq)=1/(te-t0); disp(['f=',num2str(freq(ifreq))]) 
  [t,xout] = ode45(@hydro_mount_f,[t0,te],x0); 

% excitation  
  arg=2*pi/q*log(p./(p-q*t)); se=sin(arg); ce=cos(arg); 
  
% element force = force in main spring + fluid force 
  u=amp*se;  f = cm*u;
  for i=1:length(f), f(i)=f(i)+f_smooth_clear((u(i)-xout(i,1)),cf,sf); end

% curve fit to force (1. harmonic):  f = f0 + fs*sin(arg) + fc*cos(arg)  
  A = [ ones(size(arg))  se  ce ] ;  coeff = A \ f ;         
  f0(ifreq) = coeff(1);  % offset
  fs(ifreq) = coeff(2);  % sine part
  fc(ifreq) = coeff(3);  % cosine part

% set initial conditions for next cycle  
  t0=te;  x0=xout(length(t),:)';

end

% calculate dynamic stiffness and phase angle (tan(psi)=beta/alpha)
cdyn = sqrt(fs.^2+fc.^2)/amp; psi  = atan2(fc,fs)*180/pi ;  

% plot frequence response
subplot(3,1,1), semilogx(freq,cdyn,'k','Linewidth',1), grid on
subplot(3,1,2), semilogx(freq, psi,'k','Linewidth',1), grid on
subplot(3,1,3), semilogx(freq,  f0,'k','Linewidth',1), grid on