% quarter car model with trailing arm suspension - step input
clear all,  close all

% globals
global g s a b d e f h r0
global mC mK mW ThetaK ThetaW
global Ts0 cs  cx cz dx damper_table
global ustep tstep

% vehicle data
qcm_nl_data

% define step input
ustep=0.05; % [m]      actuator step input
tstep=0.75; % [s]      @ t=tstep

% initial states
x0 = [ 0; 0; 0; 0; 0; 0];

% time simulation
t0=0; tE=1.5;
[tout,xout] = ode45(@qcm_nl_f,[t0,tE],x0);

% plot results
subplot(3,1,1), plot(tout,xout(:,1)), grid on
                xlabel('t [s]'), ylabel('z [m]')
subplot(3,1,2), plot(tout,xout(:,2)*180/pi), grid on
                xlabel('t [s]'), ylabel('\beta [deg]')
subplot(3,1,3), plot(tout,xout(:,3)*180/pi), grid on
                xlabel('t [s]'), ylabel('\phi [deg]')
                
                
% get chassis acceleration
zdd=zeros(size(tout));
for i=1:length(tout)
  xdot = qcm_nl_f(tout(i),xout(i,:)'); zdd(i)=xdot(4);
end

figure
subplot(3,1,1), plot(tout,xout(:,1))
                xlabel('t [s]'), ylabel('z [m]'), axis([0,tE,0,0.1])
                grid on
subplot(3,1,2), plot(tout,xout(:,2)*180/pi), axis([0,tE,-5,7])
                xlabel('t [s]'), ylabel('\beta [deg]')
                grid on
subplot(3,1,3), plot(tout,zdd/9.81), axis([0,tE,-2,4])
                xlabel('t [s]'), ylabel('chassis acceleration [g]')
                grid on  