clear all, close all
  
global  grav M  m  cS  dS  cT  FS0 FT0  FT  
global  v_veh Amp Om Psi
 
grav=9.81; sR=0.05;   % gravity [m/s^2] & reference susp. travel [m]
M=350;    m= 50;      % chassis & wheel mass (quarter car) [kg]
cS=20000; cT=220000;  % suspension & tire stiffness [N/m]
dSvar=1000:200:5000;  % suspension damping [N/(m/s)]
tE=10; v_veh=100/3.6; % simulation time [s] & vehicle velocity [km/h->m/s] 
Phi0=10e-6;w=2;n=1000; % spectral density, waviness & number of samples
Omin=2*pi/200; Omax=2*pi/0.2;  % range of frequencies 

% compute amplitudes and random phases
Om0=1; dOm=(Omax-Omin)/(n-1); Om=Omin:dOm:Omax;  
Phi=Phi0.*(Om./Om0).^(-w); Amp=sqrt(2*Phi*dOm);  
RandStream.setDefaultStream(RandStream('mt19937ar','seed',5489));
Psi=2*pi*rand(size(Om));

FS0 = M*grav;  FT0 = (m+M)*grav; % spring and tire preload

% initial values (adjust to road height)
zr0=sum(Amp.*sin(Psi));  x0 = [ zr0; zr0; 0; 0 ] ;  

% calculate merit functions for different damping values
eps_safety=zeros(size(dSvar)); eps_comfort=zeros(size(dSvar));
for k=1:length(dSvar)
  
  dS=dSvar(k);  disp(['perform simulation for dS=',num2str(dS)])  
  [tout,xout] = ode45(@qcm_simple_f,[0,tE],x0);

% normalized suspension travel  
  st = ( xout(:,1)-xout(:,2) ) / sR ; 
   
% get normalized acceleration and normalized dynamic wheel load          
  zcdd = zeros(size(tout));  FD = zeros(size(tout)); 
  for i=1:length(tout)
    xdot = qcm_simple_f(tout(i),xout(i,:)');
    zcdd(i) = xdot(3)/grav; FD(i)= (FT-FT0)/FT0; 
  end 
   
% merit functions (variation of dyn. wheel load, accel. & susp travel )
  eps_safety(k) = var(FD);  eps_comfort(k) = var(zcdd) + var(st);

end

% plot criteria versus damping values
plot(dSvar,eps_safety,'r'), hold on, grid on
plot(dSvar,eps_comfort,'--k'), legend('safety','comfort')