% Quarter-Car-Model with skyhook-damper
clear all, close all

global  grav  M  m  cS kS  dCh dWh TdS  cT
global  FS0  FT0  ftire  z_road
global  v_vel o_x0 o_y0 o_tp o_w o_h o_l

grav=9.81;           % constant of gravity [m/s^2]
M=350; m=50;         % chassis and wheel mass (Quarter Car) [kg]                 
cS=29400; kS=66.7;   % spring stiffness [N/m] and nonlinerity [1/m^2]                 
dCh=4850; dWh=3200;  % sky hook damping parameter 
TdS=0.005;           % time constant [s]
cT=220000;           % Tire Stiffness [N/m]

v_vel=80/3.6;             % vehicle velocity [km/h --> m/s] 
o_x0=2.0; o_y0=0; o_tp=2; % obstacle position [m] and type [-] 
o_w=10; o_h=0.04; o_l=3;  % obstacle width, height and length [m]

% preloads
FS0 = M*grav;  FT0 = FS0 + m*grav;
  
% time interval 
t0=0; te=1; 

% initial states (steady state & average damping) 
x0=[0;0;0;0; (dCh+dWh)/2]; 

% perform simulation  
[t,x] = ode23(@qcm_skyhook_f,[t0,te],x0);
    
% suspension travel (st>0: compression)
st = x(:,2) - x(:,1);
    
% chassis acceleration, wheel load and road
ac=zeros(size(t)); FT=zeros(size(t)); zr=zeros(size(t));
for i=1:length(t)
  xdot=qcm_skyhook_f(t(i),x(i,:)');
  ac(i)=xdot(3); FT(i)=ftire; zr(i)=z_road;
end
    
% plot results
subplot(2,2,1)
  plot(t,x(:,5),'k','Linewidth',1), title('damping constant')
subplot(2,2,2)
  plot(t,ac,'k','Linewidth',1), title('chassis acceleration')              
subplot(2,2,3)
  plot(t,st,'k','Linewidth',1), title('suspension travel & bump')
  hold on, plot(t,zr,'--b','Linewidth',1)   
subplot(2,2,4)
  plot(t,FT,'k','Linewidth',1), title('wheel load')              