% Brake and Drive Pitch (Rill 24.03.2011)
clear all, close all

% vehicle data
g  = 9.81;         % Constant of Gravity
R  = 0.30;         % Tire Radius [m]
h  = 0.59;         % Height of Center of Gravity [m]
a1 = 1.20;         % Center of Gravity --> Front Axle [m]
a2 = 1.30;         % Center of Gravity --> Rear Axle [m]
mC  = 600;         % Mass of Chassis (half vehicle) [kg]
m1  = 50;          % Mass of Front Axle [kg]
m2  = 50;          % Mass of Rear Axle [kg]
ThW1 = 1.2;        % Inertia of Front Wheels [kg m^2]
ThW2 = 1.2;        % Inertia of Rear Wheels [kg m^2]
cS1 = 22000;       % Stiffness of Front Axle Suspension [N/m]
cS2 = 28600;       % Stiffness of Rear Axle Suspension [N/m]
cT1 = 220000;      % Stiffness of Front Wheels [N/m]
cT2 = 200000;      % Stiffness of Rear Wheels [N/m]

% overall and generalized vehicle mass
mV=mC+m1+m2; mg = mV+ThW1/R^2+ThW2/R^2;

% static wheel loads
Fz1_st = a2/(a1+a2)*mC*g + m1*g;  Fz2_st = a1/(a1+a2)*mC*g + m2*g;

% all wheel drive no braking 
TD1=643;  TD2=1497;  TB1=0;  TB2=0;

% default axle kinematics
dx1 = 0; dx2 = 0; % inclination of front and rear wheel motion [-]
db1 = 0; db2 = 0; % y-rotation of front and rear knuckle [rad/m]

% change inclination of front knuckle/wheel motion [-]
ivar=25;  dx_min=tan(-12/180*pi); dx_max=tan(12/180*pi);

for i=1:ivar
  
  dx1 = dx_min + (dx_max-dx_min)*(i-1)/(ivar-1);

% vehicle acceleration
  xddot = 1/R*(TD1+TD2-TB1-TB2)/mg;

% dynamic tire forces
  Fx1=(TD1-TB1)/R - ThW1/R^2*xddot;
  Fx2=(TD2-TB2)/R - ThW2/R^2*xddot;
  Fz1=-xddot*((ThW1+ThW2)/R+(m1+m2)*R+mC*h)/(a1+a2);
  Fz2= xddot*((ThW1+ThW2)/(R*h)+(m1+m2)*R/h+mC)*h/(a1+a2);

% dynamic suspension forces 
  FS1=Fz1+(dx1-R*db1)*Fx1+db1*TD1-(dx1*m1+db1*ThW1/R)*xddot;
  FS2=Fz2+(dx2-R*db2)*Fx2+db2*TD2-(dx2*m2+db2*ThW2/R)*xddot;

% suspension travel
  z1 = FS1/cS1;  z2=FS2/cS2;  

% pitch and hub motion of chassis
  bC = (Fz1/cT1-Fz2/cT2+z1-z2)/(a1+a2);   zC = a1*bC-z1-Fz1/cT1;    
  
% plot pitch angle  
  plot(dx1,bC*180/pi,'ok','MarkerSize',5), hold on, grid on
  
end