% Wheel Tire Dynamics via simple 2d-model, Rill: 10.03.2011
clear all, close all

global  gravity mass theta a1 a2 h csf dsf csr dsr thetaw r  
global  fzn  dfx0 fxm sxm fxs sxs  vn  cx dx
global  t_tqb set_tqb  dn  dtqb_inc dtqb_dec 
global  sx fx fz  tqba 

% vehicle data
v0 = 80/3.6;    % [km/h -> m/s] initial vehicle velocity
gravity = 9.81; % [m/s^2] constant of gravity
mass  = 700;    % [kg] corresp. vehicle mass 
theta = 1000;   % [kgm^2] corresp. vehicle inertia of wheel
a1 = 1.2;       % [m] distance vehicle center front axle
a2 = 1.3;       % [m] distance vehicle center rear axle
h  = 0.55;      % [m] height of vehicle center
csf = 20000;    % [N/m] suspension stiffness front
dsf =  3000;    % [N/m] suspension damping front
csr = 25000;    % [N/m] suspension stiffness rear
dsr =  3200;    % [N/m] suspension damping rear
thetaw = 1.2;   % [kgm^2] wheel inertia 
r = 0.3;        % [m] wheel radius

% long. tire characteristic for payload only
mu_l = 1.0;       % [-] local friction coefficient
fzn  = 3000;      % [N] payload
dfx0 = 100000;    % [N/-] initial incl. long. force char.
fxm  = 3200*mu_l; % [N] maximum long. force
sxm  = 0.1*mu_l;  % [-] sx where fx=fxm
fxs  = 3000*mu_l; % [N] long. sliding force
sxs  = 0.8*mu_l;  % [-] sx where fx=fxs
cx = 160000;      % [N/m] longitudinal tire stiffness
dx =  500;        % [N/(m/s)] longitudinal tire damping
vn = 0.01;        % [m/s] fictitious velocity

% adjust "damping" constant in enhanced braking torque model to wheel/tire
dn = r*sqrt(cx*thetaw);

% brake control (simple ABS)
dtqb_inc = r*fxm/0.1;    % [Nm/s] amount of braking torque increase  
dtqb_dec = -2*dtqb_inc;  % [Nm/s] amount of braking torque decrease 

% set braking torque (lookup table: time [s], torque [Nm])
t_tqb   = [ 0.0  0.05  0.10   2.50 ]; 
set_tqb = [ 0.0  0.00  1.00   1.00 ]*2*fxm*r;   
 
% simple initial states
x0=[ 0; 0; 0;  v0; 0; 0;  v0/r; v0/r; 0; 0;  0; 0 ]; 

% ode23 with slightly enlarged error tolerances
options=odeset('AbsTol',1.e-5,'RelTol',5.e-3);
tic, [t,xout]=ode23(@vehicle_2d_simple_f,[0,max(t_tqb)],x0,options); toc, 

% post processing
n=length(t);sxi=zeros(n,2);fxi=sxi;fzi=sxi;tqbi=sxi;xpi=zeros(size(xout));
for i=1:n
  xp = vehicle_2d_simple_f(t(i),xout(i,:)');
  sxi(i,:)=sx'; fxi(i,:)=fx'; fzi(i,:)=fz'; tqbi(i,:)=tqba'; xpi(i,:)=xp';
end

subplot(2,3,1)
 plot(t,tqbi(:,1:2)), grid on, axis([0,max(t_tqb),0,2000])
 title('applied braking torques [Nm]'), legend('front','rear')
subplot(2,3,2)
 plot(t,xpi(:,4)/gravity), grid on, axis([0,max(t_tqb),-1.2,0])
 legend('normalized vehicle acceleration [-]') 
subplot(2,3,3); 
 plot(t,[r*xout(:,7:8),xout(:,4)]), grid on, axis([0,max(t_tqb),0,25])
 title('Velocities [m/s]'), legend('v','r \Omega_1','r \Omega_2')
subplot(2,3,4)
 plot(t,fxi(:,1:2)/(mass*gravity)),  grid on, axis([0,max(t_tqb),-1,0])
 title('normalized Longitudinal forces [N]'), legend('front','rear')
subplot(2,3,5)
 plot(t,fzi(:,1:2)/(mass*gravity)),  grid on, axis([0,max(t_tqb),0,1])
 title('normalized Vertical forces [N]'), legend('front','rear')
subplot(2,3,6)
 plot(t,sxi(:,1:2)), grid on, axis([0,max(t_tqb),-0.2,0])
 title('longitudinal slips'), legend('front','rear')