% Camber-Compensation
% Georg Rill, April 2011
%
clear all, close all
%
% vehicle data
g  = 9.81 ;  % [m/s^2] constant of cravity
ay = 0.75*g; % [m/s^2] set lateral acceleration
mc = 600;    % [kg]    chassis mass
mw =  50;    % [kg]    mass of each knuckle and wheel
s  = 1.5;    % [m]     track width
h0 = 0.6;    % [m]     height of center of gravity
r0 = 0.3;    % [m]     static tire radius
cs = 20000;  % [N/m]   suspension stiffness
cb = 10000;  % [N/m]   stiffness of anti roll bar
cy =180000;  % [N/m]   tire lateral stiffness
cz =200000;  % [N/m]   tire radial stiffness

% axle kinematics
dydz = 0 ;   % [-] lateral motion of wheel center caused by vertical
dadz = 0/180*pi; % [Grad/m] camber change caused by vertical motion

hr = h0-r0 ; sh = s/2;  dyqdz = dydz + r0*dadz; % some abbreviations

% stiffness matrix (column by column)
K(:,1) = [        2*cy         ; ...
                   0           ; ...     
                2*cy*h0        ; ...
                cy*dyqdz       ; ...
               -cy*dyqdz       ];
K(:,2) = [         0           ; ...
                  2*cz         ; ...
                   0           ; ...
                   cz          ; ...
                   cz          ];
K(:,3) = [       2*cy*h0       ; ...
                    0          ; ...
           2*cz*sh^2+2*cy*h0^2 ; ...
            sh*cz+h0*dyqdz*cy  ; ...
           -sh*cz-h0*dyqdz*cy  ];
K(:,4) = [        cy*dyqdz     ; ...
                     cz        ; ...
             sh*cz+h0*dyqdz*cy ; ...
           cs+cb+cz+dyqdz^2*cy ; ...
                  -cb          ];
K(:,5) = [      -cy*dyqdz      ; ...
                    cz         ; ...
           -sh*cz-h0*dyqdz*cy  ; ...
                     -cb       ; ...
          cs+cb+cz+dyqdz^2*cy  ];

b = -[ mc+2*mw;  0;  2*mw*hr;  mw*dydz; -mw*dydz ]*ay;  % right hand side             

x = K\b; % solve set of linear eqautions and display results  
disp(['lateral displacement of chassis  y_C =',num2str(x(1))])
disp(['vertical displacement of chassis z_C =',num2str(x(2))])
disp(['roll motion of chassis       alpha_C =',num2str(x(3)*180/pi)])
disp(['suspension travel inner wheel    z_1 =',num2str(x(4))])
disp(['suspension travel outer wheel    z_2 =',num2str(x(5))])

% compute and display wheel loads
Fz1=(mw+mc/2)*g+cz*(x(2)+s/2*x(3)+x(4)); disp(['Fz1=',num2str(Fz1)])
Fz2=(mw+mc/2)*g+cz*(x(2)-s/2*x(3)+x(5)); disp(['Fz2=',num2str(Fz2)])