% Track Model Vehicle and Trailer or Tractor-Semitrailer
clear all, close all
%
global a b c v  t_d d_i

% vehicle data
a = 2.6;    % wheel base [m]
b = 1.0;    % distance rear axle --> coupling point [m]
c = 2.0;    % coupling point --> trailer axle [m]
v = 5./3.6; % driving velocity [km/h --> m/s]

% define lookup table for steer input [time, steering angle] 
t_d = [  0  20  30 ] ;
d_i = [  0  45  45 ]*pi/180 ; % deg --> rad

% get time interval
t0 = t_d(1);  te = t_d(length(t_d)) ;

% initial conditions (vehicle position and orientation)
x0 = 0;  y0 = 0;  ga0 = 0/180*pi ;  % yaw angle [deg --> rad]
% bending angle adjusted to steering angle (steady state solution)
d0 = interp1 ( t_d, d_i, t0 );
ka0= asin(-c*tan(d0)/sqrt((b*tan(d0))^2+a^2)) - atan2(b*tan(d0),a) ;

% time simulation
[t,xout] = ode23(@track_model_f, [t0,te], [x0; y0; ga0;  ka0]);
 
% post processing
d = interp1(t_d,d_i,t); % time history of steering angle 
kas= asin(-c*tan(d)./sqrt((b*tan(d)).^2+a^2))-atan2(b*tan(d),a); % bend angle st
x1 = xout(:,1)+a*cos(xout(:,3)); y1 = xout(:,2)+a*sin(xout(:,3)); % front axle
x2 = xout(:,1); y2 = xout(:,2); % rear axle
x3 = xout(:,1)-b*cos(xout(:,3)) - c*cos(xout(:,3)+xout(:,4)); % trailer x
y3 = xout(:,2)-b*sin(xout(:,3)) - c*sin(xout(:,3)+xout(:,4)); % trailer y

% plot some results
subplot(2,2,1)
plot(t,d*180/pi), title('\delta(t) [deg]'), grid on
subplot(2,2,2)
plot(t,v^2/a*tan(d)/9.81), title('a_y/g [-]'), grid on
subplot(2,2,3), hold on, grid on
plot(x1,y1,'k'), plot(x2,y2,'--b'),plot(x3,y3,'r'), title('path of axles')
axis equal, xlabel('[m]'), ylabel('[m]'), legend('Front','Rear','Trailer')
subplot(2,2,4) 
plot(t,[xout(:,4),kas]*180/pi), title('\kappa(t) (dyn+st) [deg]'), grid on