function eps2 = truck4a_eps2(x)

global grav m k  a11 a12  a21 a22  csf csr  v  d11 d12

rho = x(1); % curvature
be  = x(2); % side slip angle at cog
cr  = x(3); % cornering resistance

om = v*rho; % angular velocity
fd = m*grav*cr; % driving force
vx = v*cos(be); % velocity in longitudinal direction of vehicle

% longitudinal forces
fx11 = 0.5*k*fd; fx12 = fx11; fx21 = 0.5*(1-k)*fd; fx22 = fx21;

% lateral slips (sx=0 assumed)
vy11 = v*sin(be)+a11*om; 
sy11 = -(-sin(d11)*vx+cos(d11)*vy11)/(cos(d11)*vx+sin(d11)*vy11);
vy12 = v*sin(be)+a12*om;
sy12 = -(-sin(d12)*vx+cos(d12)*vy12)/(cos(d12)*vx+sin(d12)*vy12);
vy21 = v*sin(be)-a21*om;  sy21 = - vy21/vx ;
vy22 = v*sin(be)-a22*om;  sy22 = - vy22/vx ;

% lateral forces (linearized)
fy11 = csf*sy11; fy12 = csf*sy12; fy21 = csr*sy21; fy22 = csr*sy22;

% force and torque balances
fx = fx11*cos(d11)-fy11*sin(d11) + fx21 ...
   + fx12*cos(d12)-fy12*sin(d12) + fx22  +  m*v^2*rho*sin(be);
fy = fx11*sin(d11)+fy11*cos(d11) + fy21 ... 
   + fx12*sin(d12)+fy12*cos(d12) + fy22  -  m*v^2*rho*cos(be);
tz = a11*(fx11*sin(d11)+fy11*cos(d11)) - a21*fy21 ...
   + a12*(fx12*sin(d12)+fy12*cos(d12)) - a22*fy22;

% overall quadratic error
eps2 = fx^2 + fy^2 + tz^2;

end