clear all, close all

global  grav m k  a11 a12  a21 a22  csf csr  v d11 d12 

% data
grav = 9.81; % [m/s^2] constant of gravity
m = 32000; % [kg] mass of vehicle
k = 0.0; % [-] drive torque distribution (rear wheel drive)
a11 = 3.3750; % [m] cog --> midth of first front axle
a12 = 1.6250; % [m] cog --> midth of second front axle
a21 = 1.2500; % [m] cog --> midth of first rear axle
a22 = 2.7500; % [m] cog --> midth of second rear axle
csf = 2*300000; % [N/-] front axle cornering stiffness  
csr = 4*280000; % [N/-] rear axle cornering stiffness  
v = 5/3.6; % [km/h --> m/s] vehicle velocity (low speed)
d11var=linspace(5,55,11)/180*pi; % range of steering angle 11
d12var=linspace(5,45, 9)/180*pi; % range of steering angle 12

% pre-allocate cornering resistance to speed up loops
n11=length(d11var); n12=length(d12var); crvar=zeros(n11,n12);

% solve nonlinear equations (trivial starting values)
for i=1:n11 
  d11=d11var(i);
  for j=1:n12
    d12=d12var(j);
    x = fminsearch(@truck4a_eps2,[0; 0; 0]);
    rho=x(1);  be=x(2); cr=x(3);  crvar(i,j)=cr;
  end
end

% plot cornering resistance as a function of d11 and d12
contour3(d12var*180/pi,d11var*180/pi,crvar,100) 
title('Cornering resistance'),xlabel('\delta_1_2'),ylabel('\delta_1_1') 

% compute and plot cornering resistance for the Ackermann geometry
d12a=atan2(((a21+a22)/2+a12)*tan(d11var),(a21+a22)/2+a11); cr=zeros(size(d12a));
for i=1:length(d12a)
  d11=d11var(i); d12=d12a(i);
  x = fminsearch(@truck4a_eps2,[0; 0; 0]); cr(i)=x(3);
end
hold on, plot3(d12a*180/pi,d11var*180/pi,cr)
axis([5  45    5   55   0  0.6])  
view(-55,25)